==> zither-1.1.11.tar.gz: zither_prj/apollon/monitor_cut_edit.php <==
<?php
/* date */
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(3)){
   exit;
   }

require("./socket.inc");
require("./list_file_upload.inc");



echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

// function WinCls(){
//        window.close()
//                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

$GEN = $_GET["GEN"];
$come = $_GET["COME"];
$sign = $_GET["SIGN"];
$proto = $_GET["PROTO"];
$com = $_GET["COM"];
$cip = $_GET["CIP"];
$port = $_GET["PORT"];
$wtime = $_GET["WTIME"];
$pinfo = $_GET["PINFO"];
$prino = $_GET["PRINO"];
$free1 = $_GET["FREE1"];
$free4 = $_GET["FREE4"];
$select = $_GET["SELECT"];
$block_new = $_GET["BLOCK_NEW"];
$delete_check = $_GET["DEL_CHECK"];

$new_cname_ok = 0;
$count = 0;
$SE="LIKE";
$EE="=";

// ----- DB ³ ----//
$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


// ------ ѹƤκ select_get-----//
if(0 != strlen($select)){
   $select_get = urldecode($select);
// print("GET SELECT DATA(select_get) = $select_get \n");
   $select_data = "update monitor set ";
   }
else{
   echo "NG NOT WHER DATA! \n";
   exit;
   }

// ------- ǡκ select_data------- //
if(0 != strlen($come)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " come='$come'";
   }
if(0 != strlen($sign)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " sign='$sign'";
   }
if(0 != strlen($proto)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " proto='$proto'";
   }
if(0 != strlen($com)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " com='$com'";
   }
if(0 != strlen($cip)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " cip='$cip'";
   }
if(0 != strlen($port)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " port='$port'";
   }
if(0 != strlen($wtime)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " wtime='$wtime'";
   }
if(0 != strlen($pinfo)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " pinfo='$pinfo'";
   }
if(0 != strlen($prino)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " prino='$prino'";
   }
if(0 != strlen($free1)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " free1='$free1'";
   }


if(0 == strlen($block_new)){     // ֥å̵
   if(0 != strlen($free4)){
      if($count > 0){
         $select_data = $select_data . ", ";
         }
      $count++; 

      $select_data = $select_data . " free4='$free4'";

      print("$free4 ˴ޤޤƻ֥åĴޤ\n");
      $result = pg_query($conn, "select * from userblock where bname='$free4'");
      if(!$result){
         print("bud query set\n");
         exit;
         }
      $num = pg_num_rows($result);
      if($num > 0){
         while($s < $num){
            $NEW_CNAME = rtrim(pg_fetch_Result($result, $s, cname));
            print("ƻ֥åѹ򤵤Ƥޤ   $NEW_CNAME $free4\n");
            $select_data = $select_data . ", ";
            $select_data = $select_data . " cname='$NEW_CNAME'";

            print($NEW_CNAME);
            $new_cname_ok = 1;
            $s++;
            }
         }
      else{
         print("ƻ֥åѹ򤵤ƤޤƤޤ $free4\n");
         exit;
         } 
      pg_free_result($result);
      }
   }


print("DELETE_CHECK = $delete_check\n");
print("COUNT = $count\n");
print("BLOCK_NEW = $block_new\n");
print("(select_get) = $select_get\n");
print("ȿǤ(select_data) = $select_data\n");



if(0 == strlen($delete_check)){     // ˤʤäƤʤ
   if(0 == $count){
      if(0 == strlen($block_new)){     // ֥åꤵƤʤ
         print("NG SELECT DATA ERR ѹ̵Τǽλޤ\n");
         exit;
         }
      }
   }
else{
   print("꤬ͭǤΤǡ֥åѿ϶ˤޤ \n");
   $block_new = "";
   }


if(0 == strlen($block_new)){     // ֥å̵

   if(0 == strlen($delete_check)){     // ˤʤäƤʤ
      print("ԡ֥å򤵤ƤʤΤǡľ˾񤭤ޤ\n");
      $select_data = $select_data . " $select_get";
      print("UPDATE COMMAND(select_data) = $select_data\n");
      }
   else{ 
      print("ԡ֥å򤵤Ƥʤλ꤬ƤޤΤǤ\n");
      $select_data = "DELETE FROM monitor " . " $select_get";
      print("DELETE COMMAND(select_data) = $select_data\n");
      }


   // --- ѹCNAMEꥹ ----//
   $result = pg_query($conn, "select distinct(cname) from monitor $select_get");
   if(!$result){
      print("NG bud query\n");
      exit;
      }
   $num = pg_num_rows($result);
   if($num <= 0){
      print("no data\n");
      exit;
      }
   else{
      $cname_count =0;
      while($cname_count < $num){
         $cname_data[$cname_count]  = rtrim(pg_fetch_Result($result, $cname_count, cname));
         print("ѹ饤ȡ $cname_data[$cname_count]  ֹ桡 $cname_count");
         print("\n");
         $cname_count++;
         }
      }
   if($cname_count < 0){
      print("NG:  ѹ饤ȤΥꥹȤޤǤ \n");
      exit;
      }

   //------ DBѹ -----//
   if(0 == strlen($select_data)){
      print("NG NOT select_data");
      exit;
      }
   else{
      $result = pg_query($conn, "$select_data");
      print("ƻѹ夦Ǥ\n");
      if(!$result){
         print("NG bud query $select_data\n");
         exit;
         }
      $num = pg_num_rows($result);
      if($num < 0){
         print("NG ƻ֥å꤬ѹƤޤ\n");
         exit;
         }
      }

   print("OK DBѹϴλޤ\n");

   //------ եȿǡCNAMEΥꥹȤ -----//
   printf("եȿǤƤޤ\n");
   if($cname_count < 0){
      exit;
      }
   else{
      for($count = 0; $count < $cname_count; $count++){
         print("ѹ饤(1)  $cname_data[$count]  ֹ桡 $count");
         print("\n");
         list_file_upload($cname_data[$count], $GEN);
         }
      }

   if($new_cname_ok == 1){
      print("֥åѹȼեUPѹ饤(2) $NEW_CNAME");
      print("\n");
      list_file_upload($NEW_CNAME, $GEN);
      }

   }  // ֥å̵











else{  // ֥åä

   print("ԡ֥å ($block_new) 򤵤ƤޤΤǡԡޤ\n");
   print("ǡѹϹԤޤ\n");

   // ֥å̾бCNAME򸡺
   $result=pg_query($conn,"select distinct(cname) from userblock where bname='$block_new';");
   if(!$result){
      print("bname , canem select , bud query\n");
      exit;
      }
   $num = pg_num_rows($result);
   if($num > 0){
      $cname_new = rtrim(pg_fetch_Result($result, 0, cname));
      print("б륯饤̾ $cname_new Ǥ\n");
      }
   else{
      print("$block_new б륯饤̾¸ߤޤ\n");
      exit;
      }
   pg_free_result($result);
   $num = 0;

   //------ DBѹ -----//
   if(0 == strlen($select_get)){
      print("NG NOT select_get");
      exit;
      }
   else{

      $select_get_data = "select * from monitor " . $select_get;

      $result = pg_query($conn, "$select_get_data");
      print("Ϥޤ\n");
      if(!$result){
         print("NG bud query $select_get_data\n");
         exit;
         }
      $num = pg_num_rows($result);
      if($num <= 0){
         print("NG ƻ֥å꤬ѹƤޤ\n");
         exit;
         }
      else{
         $ss = 0;
         while($ss < $num){

            if(0 == strlen($come)){ $COME = rtrim(pg_fetch_Result($result, $ss, come)); }
            else{ $COME = $come; }
            if(0 == strlen($monitor)){ $MONITOR = rtrim(pg_fetch_Result($result, $ss, monitor)); }
            else{ $MONITOR = $monitor; }
            if(0 == strlen($sign)){ $SIGN = rtrim(pg_fetch_Result($result, $ss, sign)); }
            else{ $SIGN = $sign; }
            if(0 == strlen($proto)){ $PROTO = rtrim(pg_fetch_Result($result, $ss, proto)); }
            else{ $PROTO = $proto; }
            if(0 == strlen($com)){ $COM = rtrim(pg_fetch_Result($result, $ss, com)); }
            else{ $COM = $com; }
            if(0 == strlen($cip)){ $CIP = rtrim(pg_fetch_Result($result, $ss, cip)); }
            else{ $CIP = $cip; }
            if(0 == strlen($port)){ $PORT = rtrim(pg_fetch_Result($result, $ss, port)); }
            else{ $PORT = $port; }
            if(0 == strlen($wtime)){ $WTIME = rtrim(pg_fetch_Result($result, $ss, wtime)); }
            else{ $WTIME= $wtime; }
            if(0 == strlen($pinfo)){ $PINFO = rtrim(pg_fetch_Result($result, $ss, pinfo)); }
            else{ $PINFO = $pinfo; }
            if(0 == strlen($prino)){ $PRINO = rtrim(pg_fetch_Result($result, $ss, prino)); }
            else{ $PRINO = $prino; }
            if(0 == strlen($free1)){ $FREE1 = rtrim(pg_fetch_Result($result, $ss, free1)); }
            else{ $FREE1 = $free1; }
            if(0 == strlen($free2)){ $FREE2 = rtrim(pg_fetch_Result($result, $ss, free2)); }
            else{ $FREE2 = $free2; }
            if(0 == strlen($free3)){ $FREE3 = rtrim(pg_fetch_Result($result, $ss, free3)); }
            else{ $FREE3 = $free3; }

//          $UNO = rtrim(pg_fetch_Result($result, $ss, uno));

print("UNO=$UNO, $COME, $MONITOR, $SIGN, $PROTO, $COM, $CIP, $PORT, $WTIME, $PINFO, $PRINO, $block_new, $cname_new\n");

            $result2 = pg_query($conn, "insert into monitor values (
             '$COME',
             '$cname_new',
             '$MONITOR',
             $SIGN,
             '$PROTO',
             '$COM',
             '$CIP',
             '$PORT',
             $WTIME,
             '$PINFO',
             $PRINO,
             '$FREE1',
             '$FREE2',
             '$FREE3',
             '$block_new')
             ");
            if(!$result2){
               print("bud query set\n");
               exit;
               }
            pg_free_result($result2);


            $ss++;
            }
         $ss = 0;
         }
      pg_free_result($result);
      }

   print("OK DBѹϴλޤ\n");


   //------ եȿ -----//

   printf("եȿǤƤޤ\n");
   print("ѹ饤(1)  $cname_new \n");
   list_file_upload($cname_new, $GEN);

   } 




pg_Close($conn);

?>

</pre>
</body>
</html>

==> zither-1.1.15.tar.gz: zither_prj/apollon/monitor_cut_edit.php <==
<?php
/* date */
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(3)){
   exit;
   }




echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

// function WinCls(){
//        window.close()
//                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

$GEN = enco($_GET["GEN"]);
$come = enco($_GET["COME"]);
$sign = enco($_GET["SIGN"]);
$proto = enco($_GET["PROTO"]);
$com = enco($_GET["COM"]);
$cip = enco($_GET["CIP"]);
$port = enco($_GET["PORT"]);
$wtime = enco($_GET["WTIME"]);
$pinfo = enco($_GET["PINFO"]);
$prino = enco($_GET["PRINO"]);
$free1 = enco($_GET["FREE1"]);
$free4 = enco($_GET["FREE4"]);
$select = enco($_GET["SELECT"]);
$block_new = enco($_GET["BLOCK_NEW"]);
$delete_check = enco($_GET["DEL_CHECK"]);

$new_cname_ok = 0;
$count = 0;
$SE="LIKE";
$EE="=";

// ----- DB ³ ----//
$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


// ------ ѹƤκ select_get-----//
if(0 != strlen($select)){
   $select_get = urldecode($select);
// print("GET SELECT DATA(select_get) = $select_get \n");
   $select_data = "update monitor set ";
   }
else{
   echo "NG NOT WHER DATA! \n";
   exit;
   }

// ------- ǡκ select_data------- //
if(0 != strlen($come)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " come='$come'";
   }
if(0 != strlen($sign)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " sign='$sign'";
   }
if(0 != strlen($proto)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " proto='$proto'";
   }
if(0 != strlen($com)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " com='$com'";
   }
if(0 != strlen($cip)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " cip='$cip'";
   }
if(0 != strlen($port)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " port='$port'";
   }
if(0 != strlen($wtime)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " wtime='$wtime'";
   }
if(0 != strlen($pinfo)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " pinfo='$pinfo'";
   }
if(0 != strlen($prino)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " prino='$prino'";
   }
if(0 != strlen($free1)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " free1='$free1'";
   }


if(0 == strlen($block_new)){     // ֥å̵
   if(0 != strlen($free4)){
      if($count > 0){
         $select_data = $select_data . ", ";
         }
      $count++; 

      $select_data = $select_data . " free4='$free4'";

      print("$free4 ˴ޤޤƻ֥åĴޤ\n");
      $result = pg_query($conn, "select * from userblock where bname='$free4'");
      if(!$result){
         print("bud query set\n");
         exit;
         }
      $num = pg_num_rows($result);
      if($num > 0){
         while($s < $num){
            $NEW_CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
            print("ƻ֥åѹ򤵤Ƥޤ   $NEW_CNAME $free4\n");
            $select_data = $select_data . ", ";
            $select_data = $select_data . " cname='$NEW_CNAME'";

            print($NEW_CNAME);
            $new_cname_ok = 1;
            $s++;
            }
         }
      else{
         print("ƻ֥åѹ򤵤ƤޤƤޤ $free4\n");
         exit;
         } 
      pg_free_result($result);
      }
   }


print("DELETE_CHECK = $delete_check\n");
print("COUNT = $count\n");
print("BLOCK_NEW = $block_new\n");
print("(select_get) = $select_get\n");
print("ȿǤ(select_data) = $select_data\n");



if(0 == strlen($delete_check)){     // ˤʤäƤʤ
   if(0 == $count){
      if(0 == strlen($block_new)){     // ֥åꤵƤʤ
         print("NG SELECT DATA ERR ѹ̵Τǽλޤ\n");
         exit;
         }
      }
   }
else{
   print("꤬ͭǤΤǡ֥åѿ϶ˤޤ \n");
   $block_new = "";
   }


if(0 == strlen($block_new)){     // ֥å̵

   if(0 == strlen($delete_check)){     // ˤʤäƤʤ
      print("ԡ֥å򤵤ƤʤΤǡľ˾񤭤ޤ\n");
      $select_data = $select_data . " $select_get";
      print("UPDATE COMMAND(select_data) = $select_data\n");
      }
   else{ 
      print("ԡ֥å򤵤Ƥʤλ꤬ƤޤΤǤ\n");
      $select_data = "DELETE FROM monitor " . " $select_get";
      print("DELETE COMMAND(select_data) = $select_data\n");
      }


   // --- ѹCNAMEꥹ ----//
   $result = pg_query($conn, "select distinct(cname) from monitor $select_get");
   if(!$result){
      print("NG bud query\n");
      exit;
      }
   $num = pg_num_rows($result);
   if($num <= 0){
      print("no data\n");
      exit;
      }
   else{
      $cname_count =0;
      while($cname_count < $num){
         $cname_data[$cname_count]  = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
         print("ѹ饤ȡ $cname_data[$cname_count]  ֹ桡 $cname_count");
         print("\n");
         $cname_count++;
         }
      }
   if($cname_count < 0){
      print("NG:  ѹ饤ȤΥꥹȤޤǤ \n");
      exit;
      }

   //------ DBѹ -----//
   if(0 == strlen($select_data)){
      print("NG NOT select_data");
      exit;
      }
   else{
      $result = pg_query($conn, "$select_data");
      print("ƻѹ夦Ǥ\n");
      if(!$result){
         print("NG bud query $select_data\n");
         exit;
         }
      $num = pg_num_rows($result);
      if($num < 0){
         print("NG ƻ֥å꤬ѹƤޤ\n");
         exit;
         }
      }

   print("OK DBѹϴλޤ\n");

   //------ եȿǡCNAMEΥꥹȤ -----//
   printf("եȿǤƤޤ\n");
   if($cname_count < 0){
      exit;
      }
   else{
      for($count = 0; $count < $cname_count; $count++){
         print("ѹ饤(1)  $cname_data[$count]  ֹ桡 $count");
         print("\n");
         list_file_upload($cname_data[$count], $GEN);
         }
      }

   if($new_cname_ok == 1){
      print("֥åѹȼեUPѹ饤(2) $NEW_CNAME");
      print("\n");
      list_file_upload($NEW_CNAME, $GEN);
      }

   }  // ֥å̵











else{  // ֥åä

   print("ԡ֥å ($block_new) 򤵤ƤޤΤǡԡޤ\n");
   print("ǡѹϹԤޤ\n");

   // ֥å̾бCNAME򸡺
   $result=pg_query($conn,"select distinct(cname) from userblock where bname='$block_new';");
   if(!$result){
      print("bname , canem select , bud query\n");
      exit;
      }
   $num = pg_num_rows($result);
   if($num > 0){
      $cname_new = enco_rtrim(pg_fetch_Result($result, 0, cname));
      print("б륯饤̾ $cname_new Ǥ\n");
      }
   else{
      print("$block_new б륯饤̾¸ߤޤ\n");
      exit;
      }
   pg_free_result($result);
   $num = 0;

   //------ DBѹ -----//
   if(0 == strlen($select_get)){
      print("NG NOT select_get");
      exit;
      }
   else{

      $select_get_data = "select * from monitor " . $select_get;

      $result = pg_query($conn, "$select_get_data");
      print("Ϥޤ\n");
      if(!$result){
         print("NG bud query $select_get_data\n");
         exit;
         }
      $num = pg_num_rows($result);
      if($num <= 0){
         print("NG ƻ֥å꤬ѹƤޤ\n");
         exit;
         }
      else{
         $ss = 0;
         while($ss < $num){

            if(0 == strlen($come)){ $COME = enco_rtrim(pg_fetch_Result($result, $ss, come)); }
            else{ $COME = $come; }
            if(0 == strlen($monitor)){ $MONITOR = enco_rtrim(pg_fetch_Result($result, $ss, monitor)); }
            else{ $MONITOR = $monitor; }
            if(0 == strlen($sign)){ $SIGN = enco_rtrim(pg_fetch_Result($result, $ss, sign)); }
            else{ $SIGN = $sign; }
            if(0 == strlen($proto)){ $PROTO = enco_rtrim(pg_fetch_Result($result, $ss, proto)); }
            else{ $PROTO = $proto; }
            if(0 == strlen($com)){ $COM = enco_rtrim(pg_fetch_Result($result, $ss, com)); }
            else{ $COM = $com; }
            if(0 == strlen($cip)){ $CIP = enco_rtrim(pg_fetch_Result($result, $ss, cip)); }
            else{ $CIP = $cip; }
            if(0 == strlen($port)){ $PORT = enco_rtrim(pg_fetch_Result($result, $ss, port)); }
            else{ $PORT = $port; }
            if(0 == strlen($wtime)){ $WTIME = enco_rtrim(pg_fetch_Result($result, $ss, wtime)); }
            else{ $WTIME= $wtime; }
            if(0 == strlen($pinfo)){ $PINFO = enco_rtrim(pg_fetch_Result($result, $ss, pinfo)); }
            else{ $PINFO = $pinfo; }
            if(0 == strlen($prino)){ $PRINO = enco_rtrim(pg_fetch_Result($result, $ss, prino)); }
            else{ $PRINO = $prino; }
            if(0 == strlen($free1)){ $FREE1 = enco_rtrim(pg_fetch_Result($result, $ss, free1)); }
            else{ $FREE1 = $free1; }
            if(0 == strlen($free2)){ $FREE2 = enco_rtrim(pg_fetch_Result($result, $ss, free2)); }
            else{ $FREE2 = $free2; }
            if(0 == strlen($free3)){ $FREE3 = enco_rtrim(pg_fetch_Result($result, $ss, free3)); }
            else{ $FREE3 = $free3; }

//          $UNO = enco_rtrim(pg_fetch_Result($result, $ss, uno));

print("UNO=$UNO, $COME, $MONITOR, $SIGN, $PROTO, $COM, $CIP, $PORT, $WTIME, $PINFO, $PRINO, $block_new, $cname_new\n");

            $result2 = pg_query($conn, "insert into monitor values (
             '$COME',
             '$cname_new',
             '$MONITOR',
             $SIGN,
             '$PROTO',
             '$COM',
             '$CIP',
             '$PORT',
             $WTIME,
             '$PINFO',
             $PRINO,
             '$FREE1',
             '$FREE2',
             '$FREE3',
             '$block_new')
             ");
            if(!$result2){
               print("bud query set\n");
               exit;
               }
            pg_free_result($result2);


            $ss++;
            }
         $ss = 0;
         }
      pg_free_result($result);
      }

   print("OK DBѹϴλޤ\n");


   //------ եȿ -----//

   printf("եȿǤƤޤ\n");
   print("ѹ饤(1)  $cname_new \n");
   list_file_upload($cname_new, $GEN);

   } 




pg_Close($conn);

?>

</pre>
</body>
</html>
